<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>MX Package Installer</source>
        <translation>MX パッケージインストーラ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>通常のアプリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation>カテゴリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>パッケージ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="420"/>
        <location filename="../mainwindow.ui" line="817"/>
        <location filename="../mainwindow.ui" line="1074"/>
        <source>Description</source>
        <translation>説明</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;通常のパッケージ管理を行います&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="190"/>
        <location filename="../mainwindow.ui" line="686"/>
        <location filename="../mainwindow.ui" line="1099"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.ui" line="699"/>
        <location filename="../mainwindow.ui" line="1167"/>
        <location filename="../mainwindow.ui" line="1431"/>
        <source>= Installed packages</source>
        <translation>= インストール済みパッケージ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Enabled Repos</source>
        <translation>有効なリポジトリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remove all the packages that are marked as &amp;quot;autoremovable&amp;quot;. If you want to manage them, select Autoremovable from drop-down selection box.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&amp;quot;自動削除可能&amp;quot;とマークされたパッケージをすべて削除します。この操作を実行するには、ドロップダウンの選択ボックスから自動削除可能を選択してください。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Autoremove packages</source>
        <translation>パッケージの自動削除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="1324"/>
        <source>Upgrade All</source>
        <translation>全てアップグレード</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.ui" line="926"/>
        <source>Installed:</source>
        <translation>インストール済み：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <location filename="../mainwindow.ui" line="540"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Total packages:</source>
        <translation>合計のパッケージ数：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="987"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>「推奨」パッケージもインストールします</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="577"/>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Upgradable:</source>
        <translation>アップグレード可能：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <location filename="../mainwindow.ui" line="584"/>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Hide library and developer packages</source>
        <translation>ライブラリと開発者のパッケージを隠します</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <location filename="../mainwindow.ui" line="633"/>
        <location filename="../mainwindow.ui" line="1006"/>
        <location filename="../mainwindow.ui" line="1524"/>
        <source>Refresh list</source>
        <translation>リストの更新</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <location filename="../mainwindow.ui" line="758"/>
        <location filename="../mainwindow.ui" line="1129"/>
        <location filename="../mainwindow.ui" line="1479"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;パッケージを状況に応じてフィルタリングします。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.ui" line="761"/>
        <location filename="../mainwindow.ui" line="765"/>
        <location filename="../mainwindow.ui" line="1132"/>
        <location filename="../mainwindow.ui" line="1136"/>
        <location filename="../mainwindow.cpp" line="3054"/>
        <source>All packages</source>
        <translation>全てのパッケージ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <location filename="../mainwindow.ui" line="770"/>
        <location filename="../mainwindow.ui" line="1141"/>
        <location filename="../mainwindow.cpp" line="3074"/>
        <source>Installed</source>
        <translation>インストール済み</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <location filename="../mainwindow.ui" line="775"/>
        <location filename="../mainwindow.ui" line="1146"/>
        <location filename="../mainwindow.cpp" line="3075"/>
        <source>Upgradable</source>
        <translation>アップグレード可能</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="503"/>
        <location filename="../mainwindow.ui" line="780"/>
        <location filename="../mainwindow.ui" line="1151"/>
        <location filename="../mainwindow.ui" line="1516"/>
        <location filename="../mainwindow.cpp" line="3039"/>
        <location filename="../mainwindow.cpp" line="3076"/>
        <location filename="../mainwindow.cpp" line="3178"/>
        <location filename="../mainwindow.cpp" line="3179"/>
        <source>Not installed</source>
        <translation>未インストール</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="785"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <location filename="../mainwindow.cpp" line="2574"/>
        <location filename="../mainwindow.cpp" line="3010"/>
        <location filename="../mainwindow.cpp" line="3077"/>
        <location filename="../mainwindow.cpp" line="3163"/>
        <source>Autoremovable</source>
        <translation>自動削除可能</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <location filename="../mainwindow.ui" line="727"/>
        <location filename="../mainwindow.ui" line="855"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation>= アップグレード可能なパッケージ。新しいバージョンが選択したリポジトリより入手できます。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <location filename="../mainwindow.ui" line="802"/>
        <location filename="../mainwindow.ui" line="1059"/>
        <source>Package Name</source>
        <translation>パッケージ名</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Version</source>
        <translation>バージョン</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>MX Test Repo</source>
        <translation>MX テスト版リポジトリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <location filename="../mainwindow.ui" line="807"/>
        <location filename="../mainwindow.ui" line="1064"/>
        <source>Repo Version</source>
        <translation>リポジトリのバージョン</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <location filename="../mainwindow.ui" line="812"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Installed Version</source>
        <translation>インストール済みバージョン</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="837"/>
        <source>Debian Backports</source>
        <translation>Debian バックポート</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1190"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1447"/>
        <location filename="../mainwindow.ui" line="1451"/>
        <location filename="../mainwindow.cpp" line="115"/>
        <location filename="../mainwindow.cpp" line="116"/>
        <source>For all users</source>
        <translation>すべてのユーザ向け</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>For current user</source>
        <translation>現在のユーザ向け</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1541"/>
        <source>Remote (repo):</source>
        <translation>リモート (repo):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <location filename="../mainwindow.ui" line="1486"/>
        <location filename="../mainwindow.cpp" line="3021"/>
        <source>All apps</source>
        <translation>全てのアプリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1491"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>All runtimes</source>
        <translation>全てのランタイム</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1496"/>
        <location filename="../mainwindow.cpp" line="3033"/>
        <source>All available</source>
        <translation>全ての利用可能</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1501"/>
        <location filename="../mainwindow.cpp" line="3018"/>
        <source>Installed apps</source>
        <translation>インストール済みのアプリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1506"/>
        <location filename="../mainwindow.cpp" line="3015"/>
        <source>Installed runtimes</source>
        <translation>インストール済みランタイム</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1511"/>
        <location filename="../mainwindow.cpp" line="3037"/>
        <location filename="../mainwindow.cpp" line="3171"/>
        <location filename="../mainwindow.cpp" line="3172"/>
        <source>All installed</source>
        <translation>すべてインストールします</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1303"/>
        <source>Total items </source>
        <translation>合計のアイテム</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1317"/>
        <source>Installed apps:</source>
        <translation>インストール済みのアプリ：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1369"/>
        <source>Advanced</source>
        <translation>上級者向け</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1398"/>
        <source>Total installed size:</source>
        <translation>インストール済みの合計サイズ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1412"/>
        <source>Remove unused runtimes</source>
        <translation>未使用のランタイムを削除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1249"/>
        <source>Short Name</source>
        <translation>短縮名</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1254"/>
        <source>Full Package Name</source>
        <translation>パッケージの正式な名前</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1264"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1558"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <location filename="../mainwindow.cpp" line="2935"/>
        <source>Console Output</source>
        <translation>コンソールの出力</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1564"/>
        <source>Enter</source>
        <translation>入力</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1574"/>
        <source>Respond here, or just press Enter</source>
        <translation>ここで応答するか、Enter キーを押してください</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1633"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="3064"/>
        <location filename="../mainwindow.cpp" line="3072"/>
        <location filename="../mainwindow.cpp" line="3162"/>
        <location filename="../mainwindow.cpp" line="3168"/>
        <location filename="../mainwindow.cpp" line="3463"/>
        <source>Install</source>
        <translation>インストール</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1639"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1667"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1699"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1702"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1708"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1746"/>
        <source>Display help </source>
        <translation>ヘルプの表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1749"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1755"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1771"/>
        <source>Uninstall</source>
        <translation>アンインストール（削除）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1777"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>Uninstalling packages...</source>
        <translation>パッケージを削除中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Running pre-uninstall operations...</source>
        <translation>アンインストール前の操作を実行中です...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Running post-uninstall operations...</source>
        <translation>削除後の作業を実行中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Refreshing sources...</source>
        <translation>ソースを更新中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <location filename="../mainwindow.cpp" line="1297"/>
        <location filename="../mainwindow.cpp" line="1432"/>
        <location filename="../mainwindow.cpp" line="1601"/>
        <location filename="../mainwindow.cpp" line="1666"/>
        <location filename="../mainwindow.cpp" line="1981"/>
        <location filename="../mainwindow.cpp" line="2121"/>
        <location filename="../mainwindow.cpp" line="2567"/>
        <location filename="../mainwindow.cpp" line="2586"/>
        <location filename="../mainwindow.cpp" line="2693"/>
        <location filename="../mainwindow.cpp" line="2709"/>
        <location filename="../mainwindow.cpp" line="2805"/>
        <location filename="../mainwindow.cpp" line="2838"/>
        <location filename="../mainwindow.cpp" line="3271"/>
        <location filename="../mainwindow.cpp" line="3347"/>
        <location filename="../mainwindow.cpp" line="3377"/>
        <location filename="../mainwindow.cpp" line="3479"/>
        <location filename="../mainwindow.cpp" line="3519"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>ソースの更新中に問題がありました。一部のソースではアップデートが提供されていない可能性があります。詳細はこちらをチェックしてください：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Could not determine Debian version. Please select your version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Debian Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>Please wait...</source>
        <translation>お待ちください...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1113"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>あなたは MX テスト版リポジトリを使おうとしていますが、そのパッケージはテストのみを目的として提供されています。システムを壊す可能性があるので、システムをバックアップして、一度につき一つのパッケージだけをインストールしたりアップデートすることをお勧めします。Main に移行する前にそのパッケージが評価できるように、フォーラムでフィードバックを提供してください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1122"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>あなたは Debian バックポートを使おうとしていますが、これは次回予定の Debian リリース（テスト版といわれます）から取られ、Debian 安定版で使用できるように修正しれコンパイルされたパッケージが含まれています。Debian と MX Linux の安定版リリース用に多くのテストが行われていません。また、Debian 安定版にある他のアプリと互換性がないというリスクがある状況で、現状のままで提供されています。注意して使用してください！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1130"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux は、ユーザが便利なようにとの目的のみで、この flatpaks のリポジトリを提供しているので、個々の flatpaks 自体が機能するかどうかについては責任を負いません。詳しくは、Flatpak の Wiki ページをご覧ください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1138"/>
        <location filename="../mainwindow.cpp" line="3507"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1142"/>
        <source>Do not show this message again</source>
        <translation>このメッセージを再び表示しない</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1246"/>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1262"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>以下のパッケージが選択されました。リストの変更を表示するには「詳細の表示」をクリックしてください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1298"/>
        <location filename="../mainwindow.cpp" line="1433"/>
        <location filename="../mainwindow.cpp" line="1667"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>インターネットが利用できないので、パッケージのリストがダウンロードできません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1301"/>
        <source>Installing packages...</source>
        <translation>パッケージのインストール中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1359"/>
        <source>Post-processing...</source>
        <translation>インストール後の処理中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1391"/>
        <source>Pre-processing for </source>
        <translation>次の前処理中です：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1405"/>
        <source>Installing </source>
        <translation>インストール中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1412"/>
        <source>Post-processing for </source>
        <translation>次の後処理中です：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1602"/>
        <source>There was an error downloading or writing the file: %1. Please check your internet connection and free space on your drive</source>
        <translation>ファイル %1 の書き込み中にエラーが発生しました。インターネット接続とドライブに十分な空き領域があるかをチェックしてください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <source>Downloading package info...</source>
        <translation>パッケージ情報をダウンロード中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1982"/>
        <source>dpkg-query command returned an error. Please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>dpkg-query コマンドがエラーを返しました。端末で &apos;dpkg-query -W&apos; を実行して、出力を確認してください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2122"/>
        <source>dpkg-query command returned an error, please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>dpkg-query コマンドがエラーを返しました。端末で &apos;dpkg-query -W&apos; を実行して、出力を確認してください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2243"/>
        <location filename="../mainwindow.cpp" line="2345"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <source>Package info</source>
        <translation>パッケージ情報</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2260"/>
        <location filename="../mainwindow.cpp" line="3411"/>
        <source>More &amp;info...</source>
        <translation>詳細情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2291"/>
        <source>Packages to be installed: </source>
        <translation>インストールするパッケージ: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2551"/>
        <location filename="../mainwindow.cpp" line="2563"/>
        <location filename="../mainwindow.cpp" line="2583"/>
        <location filename="../mainwindow.cpp" line="2668"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="3268"/>
        <location filename="../mainwindow.cpp" line="3343"/>
        <location filename="../mainwindow.cpp" line="3371"/>
        <location filename="../mainwindow.cpp" line="3475"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2551"/>
        <location filename="../mainwindow.cpp" line="2563"/>
        <location filename="../mainwindow.cpp" line="2583"/>
        <location filename="../mainwindow.cpp" line="2668"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="2706"/>
        <location filename="../mainwindow.cpp" line="3268"/>
        <location filename="../mainwindow.cpp" line="3343"/>
        <location filename="../mainwindow.cpp" line="3371"/>
        <location filename="../mainwindow.cpp" line="3475"/>
        <location filename="../mainwindow.cpp" line="3516"/>
        <source>Processing finished successfully.</source>
        <translation>処理は正常に終了しました。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2568"/>
        <location filename="../mainwindow.cpp" line="2587"/>
        <location filename="../mainwindow.cpp" line="3272"/>
        <location filename="../mainwindow.cpp" line="3348"/>
        <location filename="../mainwindow.cpp" line="3378"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>インストール中に問題が検出されたので、コンソール出力を検査してください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2597"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2598"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2600"/>
        <source>Package Installer for MX Linux</source>
        <translation>MX Linux 用のパッケージインストーラ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2602"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2603"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2615"/>
        <source>%1 Help</source>
        <translation>%1 のヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2693"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>アンインストールに問題が発生したので、出力をチェックしてください</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2706"/>
        <location filename="../mainwindow.cpp" line="3516"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2709"/>
        <location filename="../mainwindow.cpp" line="3519"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>プログラムをアンインストール中に問題が発生しました</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2806"/>
        <location filename="../mainwindow.cpp" line="2839"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation>パッケージの一覧がダウンロードできませんでした。APT source を確認してください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2876"/>
        <location filename="../mainwindow.cpp" line="2918"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak はインストールされていません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2877"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak は現在インストールされていません。
OK でインストールを実行しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2918"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak はインストールされませんでした</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2939"/>
        <source>Needs re-login</source>
        <translation>再ログインが必要です</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2940"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>メニューにインストールされているアイテムを表示するには、ログアウト/ログインが必要な場合があります</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3064"/>
        <location filename="../mainwindow.cpp" line="3072"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <source>Mark keep</source>
        <translation>マークの保持</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3162"/>
        <source>Upgrade</source>
        <translation>アップグレード</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3300"/>
        <source>Quit?</source>
        <translation>中止しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3301"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>プロセスが実行中の場合、終了するとシステムが不安定な状態になる可能性があります。&lt;p&gt;&lt;b&gt;本当に MXパッケージインストーラを終了しますか？&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3463"/>
        <source>Reinstall</source>
        <translation>再インストール</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3480"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>直前の操作中に問題が検出されました。端末の出力を点検してください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3508"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>潜在的に危険な操作。
削除されるパッケージのリストを十分確認してください。</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="16"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Flatpak リモートの管理</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>すべてのユーザ向け</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>現在のユーザ向け</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>enter Flatpak remote URL</source>
        <translation>Flatpak リモート URL を入力</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="38"/>
        <source>enter Flatpakref location to install app</source>
        <translation>アプリをインストールするために Flatpakref の場所を入力してください</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="40"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>flatpak リモート (repos) の追加や削除、flatpakref の URL やパスを使ってアプリのインストールなどを行います</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Remove remote</source>
        <translation>リモートの削除</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Add remote</source>
        <translation>リモートの追加</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Install app</source>
        <translation>アプリのインストール</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="64"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>取り外し不可</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="82"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub はメインの Flatpak リモートなので、削除できません</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Error adding remote</source>
        <translation>リモートの追加中にエラー発生</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>リモートを追加できませんでした - コマンドはエラーを返しました。リモートアドレスを再度確認してから、もう一度試してください</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Remote added successfully</source>
        <translation>リモートの追加に成功しました</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation>Dpkg/apt データベースが他のプログラムによってロックされています: %1

このプログラムを閉じるか、処理が終わるまで待機してから再試行してください。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation>MX パッケージインストーラは MX Linux 用のパッケージ管理ツールです。
    - さまざまなソースから人気のプログラムをインストールします
    - MX Test リポジトリにあるプログラムをインストールします
    - Debian Backports リポジトリにあるプログラムをインストールします
    - Flatpak 形式のパッケージをインストールします</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation>インターネット未接続が誤報である場合には、オンラインチェックをスキップする。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <location filename="../main.cpp" line="106"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>root としてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="107"/>
        <source>You must run this program with admin access.</source>
        <translation>このプログラムは管理者権限で実行してください。</translation>
    </message>
</context>
</TS>